@@ -289,7 +289,7 @@ class GtkUI(glchess.ui.UI):
     
     def watchFileDescriptor(self, fd):
         """Extends ui.UI"""
-        self._watches[fd] = gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_HUP, self.__readData)
+        self._watches[fd] = gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR, self.__readData)
         
     def unwatchFileDescriptor(self, fd):
         """Extends ui.UI"""
@@ -589,9 +589,8 @@ Please contact your system administrator to resolve these problems, until then y
                 glchess.config.set('show_3d', False)
                 value = False
             self.__renderGL = value
-            menuItem = self.__getWidget('menu_view_3d')
-            menuItem.set_active(self.__renderGL)
-            self.view.viewWidget.setRenderGL(self.__renderGL)
+            self.__getWidget('menu_view_3d').set_active(value)
+            self.view.viewWidget.setRenderGL(value)
                 
         elif name == 'show_comments':
             self.view.setShowComments(value)
@@ -813,7 +812,16 @@ Please contact your system administrator to resolve these problems, until then y
 
     def _on_claim_draw_clicked(self, widget):
         """Gtk+ callback"""
-        self.view.feedback.claimDraw()
+        if not self.view.feedback.claimDraw():
+            dialog = gtk.MessageDialog(flags = gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                                       type = gtk.MESSAGE_WARNING,
+                                       message_format = _("Unable to claim draw"))
+        dialog.format_secondary_text(_("""You may claim a draw when:
+a) The board has been in the same state three times (Three fold repitition)
+b) Fifty moves have occured where no pawn has moved and no piece has been captured (50 move rule)"""))
+        dialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_ACCEPT)
+        dialog.run()
+        dialog.destroy()
 
     def _on_preferences_clicked(self, widget):
         """Gtk+ callback"""
