@@ -323,14 +323,22 @@ class SudokuMaker:
                 self.played.append(line.strip('\n'))
         
     def load (self):
-        if not os.path.exists(self.pickle_to):
+        try:
             os.makedirs(self.pickle_to)
+        except os.error, e:
+            if e.errno != errno.EEXIST:
+                raise
         for cat in sudoku.DifficultyRating.categories:
             if not os.path.exists(os.path.join(self.pickle_to,
                                                cat.replace(' ','_'))):
-                shutil.copy(os.path.join(os.path.join(BASE_DIR,'puzzles'),cat.replace(' ','_')),
-                            os.path.join(self.pickle_to,cat.replace(' ','_'))
-                            )
+                try:
+                    shutil.copy(os.path.join(os.path.join(PUZZLE_DIR),cat.replace(' ','_')),
+                                os.path.join(self.pickle_to,cat.replace(' ','_')))
+                except:
+                    print 'Problem copying base puzzles'
+                    print 'Attempted to copy from ',os.path.join(os.path.join(PUZZLE_DIR),cat.replace(' ','_'))
+                    print 'to',os.path.join(self.pickle_to,cat.replace(' ','_'))
+                    raise
 
     def get_new_puzzle (self, difficulty, new=True):
         """Return puzzle with difficulty near difficulty.
@@ -402,7 +410,7 @@ class SudokuMaker:
                         puzzle_list.append(puzzle)
         return puzzle_list
 
-    def get_puzzles (self, n, levels, new=True):
+    def get_puzzles_random (self, n, levels, new=True, exclude=[]):
         """Return a list of n puzzles and difficulty values (as floats).
 
         The puzzles will correspond as closely as possible to levels.
@@ -412,6 +420,57 @@ class SudokuMaker:
         assert(levels)
         puzzles = []
         # Open files to read puzzles...
+        puzzles_by_level = {}; files = {}
+        for l in levels:
+            files[l] = os.path.join(self.pickle_to,
+                                    l.replace(' ','_'))
+            fi = file(files[l],'r')
+            puzzles_by_level[l] = fi.readlines(); fi.close()
+            random.shuffle(puzzles_by_level[l])
+        i = 0; il = 0
+        n_per_level = {}
+        finished = []
+        while i < n and len(finished) < len(levels):
+            if il >= len(levels): il = 0
+            lev = levels[il]
+            # skip any levels that we've exhausted
+            if lev in finished:
+                il += 1
+                continue
+            try:
+                line = puzzles_by_level[lev].pop()
+            except IndexError:
+                finished.append(lev)
+            else:
+                try:
+                    p,d = line.split('\t')
+                except ValueError:
+                    print 'WARNING: invalid line %s in file %s'%(line,files[lev])
+                    continue
+                if sudoku.is_valid_puzzle(p):
+                    if (p not in exclude) and (not new or p not in self.played):
+                        puzzles.append((p,float(d)))
+                        i += 1
+                else:
+                    print 'WARNING: invalid puzzle %s in file %s'%(p,files[lev])
+            il += 1
+        if i < n:
+            print 'WARNING: Not able to provide %s puzzles in levels %s'%(n,levels)
+            print 'WARNING: Generate more puzzles if you really need this many puzzles!'
+        return puzzles    
+
+    def get_puzzles (self, n, levels, new=True, randomize=True,
+                     exclude=[]):
+        """Return a list of n puzzles and difficulty values (as floats).
+
+        The puzzles will correspond as closely as possible to levels.
+        If new, we only return puzzles not yet played.
+        """
+        if randomize: return self.get_puzzles_random(n,levels,new=new,exclude=exclude)
+        if not n: return []
+        assert(levels)
+        puzzles = []
+        # Open files to read puzzles...
         files = dict([(l,
                        file(os.path.join(self.pickle_to,
                                          l.replace(' ','_')),
@@ -430,9 +489,13 @@ class SudokuMaker:
             if not line:
                 finished.append(lev)
             else:
-                p,d = line.split('\t')
+                try:
+                    p,d = line.split('\t')
+                except ValueError:
+                    print 'WARNING: invalid line %s in file %s'%(line,files[lev])
+                    continue
                 if sudoku.is_valid_puzzle(p):
-                    if not new or p not in self.played:
+                    if (p not in exclude) and (not new or p not in self.played):
                         puzzles.append((p,float(d)))
                         i += 1
                 else:
