@@ -28,12 +28,10 @@
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#if defined(HAVE_RSVG) && defined(HAVE_CAIRO)
-#define ENABLE_SCALABLE
-
+#ifdef HAVE_RSVG
 #include <librsvg/rsvg.h>
 #include <librsvg/rsvg-cairo.h>
-#endif /* HAVE_RSVG && HAVE_CAIRO */
+#endif /* HAVE_RSVG */
 
 #include "games-preimage.h"
 
@@ -43,18 +41,15 @@ struct _GamesPreimage {
   gint width;
   gint height;
 
-#ifdef ENABLE_SCALABLE
+#ifdef HAVE_RSVG
   RsvgHandle *rsvg_handle;
+  cairo_font_options_t *font_options;
 #endif
 
   /* raster pixbuf data */
   GdkPixbuf *pixbuf;
 
   guint scalable : 1;
-
-  guint antialias_set : 1;
-  guint antialias : 2; /* enough bits for cairo_antialias_t */
-  guint subpixel_order : 3; /* enough bits for cairo_subpixel_order_t */
 };
 
 G_DEFINE_TYPE (GamesPreimage, games_preimage, G_TYPE_OBJECT);
@@ -72,10 +67,13 @@ games_preimage_finalize (GObject * object)
 {
   GamesPreimage *preimage = GAMES_PREIMAGE (object);
 
-#ifdef ENABLE_SCALABLE
+#ifdef HAVE_RSVG
   if (preimage->rsvg_handle != NULL) {
     g_object_unref (preimage->rsvg_handle);
   }
+  if (preimage->font_options) {
+    cairo_font_options_destroy (preimage->font_options);
+  }
 #endif
 
   if (preimage->pixbuf != NULL) {
@@ -92,7 +90,7 @@ games_preimage_class_init (GamesPreimageClass * klass)
 
   oclass->finalize = games_preimage_finalize;
 
-#ifdef ENABLE_SCALABLE
+#ifdef HAVE_RSVG
   rsvg_init ();
 #endif
 }
@@ -116,7 +114,7 @@ games_preimage_render (GamesPreimage * preimage, gint width, gint height)
   g_return_val_if_fail (width > 0 && height > 0, NULL);
   g_return_val_if_fail (preimage != NULL, NULL);
 
-#ifdef ENABLE_SCALABLE
+#ifdef HAVE_RSVG
   if (preimage->scalable) {     /* Render vector image */
     pixbuf = games_preimage_render_sub (preimage,
                                         NULL,
@@ -128,7 +126,7 @@ games_preimage_render (GamesPreimage * preimage, gint width, gint height)
                                         ((double) height) /
                                         ((double) preimage->height));
   } else
-#endif /* ENABLE_SCALABLE */
+#endif /* HAVE_RSVG */
   {
     /* Render raster image */
     pixbuf = gdk_pixbuf_scale_simple (preimage->pixbuf,
@@ -138,7 +136,7 @@ games_preimage_render (GamesPreimage * preimage, gint width, gint height)
   return pixbuf;
 }
 
-#ifdef ENABLE_SCALABLE
+#ifdef HAVE_RSVG
 
 /* This routine is copied from librsvg:
    Copyright © 2005 Dom Lachowicz <cinamod@hotmail.com>
@@ -212,7 +210,11 @@ games_preimage_render_sub (GamesPreimage * preimage,
   if (!preimage->scalable)
     return NULL;
 
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE (1, 6, 0)
+  rowstride = cairo_format_stride_for_width (CAIRO_FORMAT_ARGB32, width);
+#else
   rowstride = width * 4;
+#endif
 
   data = g_try_malloc0 (rowstride * height);
   if (!data)
@@ -228,21 +230,10 @@ games_preimage_render_sub (GamesPreimage * preimage,
 
   cx = cairo_create (surface);
 
-  if (preimage->antialias_set) {
-    cairo_font_options_t *options;
+  if (preimage->font_options) {
+    cairo_set_antialias (cx, cairo_font_options_get_antialias (preimage->font_options));
 
-    cairo_set_antialias (cx, (cairo_antialias_t) preimage->antialias);
-
-    options = cairo_font_options_create ();
-    cairo_get_font_options (cx, options);
-    cairo_font_options_set_antialias (options,
-                                      (cairo_antialias_t) preimage->
-                                      antialias);
-    cairo_font_options_set_subpixel_order (options,
-                                           (cairo_subpixel_order_t) preimage->
-                                           subpixel_order);
-    cairo_set_font_options (cx, options);
-    cairo_font_options_destroy (options);
+    cairo_set_font_options (cx, preimage->font_options);
   }
 
   cairo_matrix_init_identity (&matrix);
@@ -275,7 +266,7 @@ games_preimage_render_sub (GamesPreimage * preimage,
   return pixbuf;
 }
 
-#endif /* ENABLE_SCALABLE */
+#endif /* HAVE_RSVG */
 
 /**
  * games_preimage_new_from_file:
@@ -296,7 +287,7 @@ games_preimage_new_from_file (const gchar * filename, GError ** error)
 
   preimage = g_object_new (GAMES_TYPE_PREIMAGE, NULL);
 
-#ifdef ENABLE_SCALABLE
+#ifdef HAVE_RSVG
   preimage->rsvg_handle = rsvg_handle_new_from_file (filename, NULL);
   if (preimage->rsvg_handle) {
     RsvgDimensionData data;
@@ -318,7 +309,7 @@ games_preimage_new_from_file (const gchar * filename, GError ** error)
 
     return preimage;
   }
-#endif /* ENABLE_SCALABLE */
+#endif /* HAVE_RSVG */
 
   /* Not an SVG */
   preimage->scalable = FALSE;
@@ -337,23 +328,27 @@ games_preimage_new_from_file (const gchar * filename, GError ** error)
 }
 
 /**
- * games_preimage_set_antialias:
- * @preimage:
- * @antialias: the antialiasing mode to use (see @cairo_antialias_t)
- * @subpixel_order: the subpixel order to use (see @cairo_subpixel_order_t)
- * if @antialias is %CAIRO_ANTIALIAS_SUBPIXEL 
+ * games_preimage_set_font_options:
+ * @preimage: a #GamesPreimage
+ * @font_options: the font options
  *
  * Turns on antialising of @preimage, if it contains an SVG image.
  */
 void
-games_preimage_set_antialias (GamesPreimage * preimage,
-                              guint antialias, guint subpixel_order)
+games_preimage_set_font_options (GamesPreimage * preimage,
+                                 const cairo_font_options_t * font_options)
 {
   g_return_if_fail (GAMES_IS_PREIMAGE (preimage));
 
-  preimage->antialias_set = TRUE;
-  preimage->antialias = antialias;
-  preimage->subpixel_order = subpixel_order;
+  if (preimage->font_options) {
+    cairo_font_options_destroy (preimage->font_options);
+  }
+
+  if (font_options) {
+    preimage->font_options = cairo_font_options_copy (font_options);
+  } else {
+    preimage->font_options = NULL;
+  }
 }
 
 /**
